<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/includes
 * @author     Orion <freelance@orionorigin.com>
 */
class Vpc_Ssa {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Vpc_Ssa_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'vpc-ssa';
		$this->version     = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Vpc_Ssa_Loader. Orchestrates the hooks of the plugin.
	 * - Vpc_Ssa_I18n. Defines internationalization functionality.
	 * - Vpc_Ssa_Admin. Defines all hooks for the admin area.
	 * - Vpc_Ssa_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vpc-ssa-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vpc-ssa-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-vpc-ssa-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-vpc-ssa-public.php';

		$this->loader = new Vpc_Ssa_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Vpc_Ssa_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Vpc_Ssa_I18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Vpc_Ssa_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_filter( 'vpc_skins_settings', $plugin_admin, 'add_social_share_settings' );
		$this->loader->add_filter( 'vpc_global_settings', $plugin_admin, 'add_ssa_global_settings' );
		$this->loader->add_action( 'vpc_add_settings_onglet', $plugin_admin, 'add_ssa_setting_onglet', 10, 4 );
		$this->loader->add_action( 'vpc_add_settings_body', $plugin_admin, 'add_ssa_setting_body', 10, 4 );
		$this->loader->add_action( 'init', $plugin_admin, 'get_updater' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Vpc_Ssa_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'vpc_enqueue_core_styles', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'vpc_enqueue_core_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'wp_ajax_get_configuration_img', $plugin_public, 'get_vpc_ssa_configuration_img' );
		$this->loader->add_action( 'wp_ajax_nopriv_get_configuration_img', $plugin_public, 'get_vpc_ssa_configuration_img' );
		$this->loader->add_action( 'language_attributes', $plugin_public, 'add_opengraph_doctype' );
		$this->loader->add_action( 'wp_head', $plugin_public, 'remove_seo_opengraph', 1 );
		$this->loader->add_action( 'wp_head', $plugin_public, 'insert_opengraph_in_head', 0 );
		$this->loader->add_action( 'wp_ajax_vpc_ssa_save_canvas_img', $plugin_public, 'vpc_ssa_save_canvas_img_in_server' );
		$this->loader->add_action( 'wp_ajax_nopriv_vpc_ssa_save_canvas_img', $plugin_public, 'vpc_ssa_save_canvas_img_in_server' );
		$this->loader->add_filter( 'vpc_data', $plugin_public, 'vpc_ssa_vars' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Vpc_Ssa_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
